Class: Aws::ConnectParticipant::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ConnectParticipant::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-connectparticipant/client.rb,
sig/client.rbs
Overview
An API client for ConnectParticipant. To construct a client, you need to configure a :region and :credentials.
client = Aws::ConnectParticipant::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CancelParticipantAuthenticationResponseSuccess, _CompleteAttachmentUploadResponseSuccess, _CreateParticipantConnectionResponseSuccess, _DescribeViewResponseSuccess, _DisconnectParticipantResponseSuccess, _GetAttachmentResponseSuccess, _GetAuthenticationUrlResponseSuccess, _GetTranscriptResponseSuccess, _SendEventResponseSuccess, _SendMessageResponseSuccess, _StartAttachmentUploadResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_participant_authentication(params = {}) ⇒ Struct
Cancels the authentication session.
-
#complete_attachment_upload(params = {}) ⇒ Struct
Allows you to confirm that the attachment has been uploaded using the pre-signed URL provided in StartAttachmentUpload API.
-
#create_participant_connection(params = {}) ⇒ Types::CreateParticipantConnectionResponse
Creates the participant's connection.
-
#describe_view(params = {}) ⇒ Types::DescribeViewResponse
Retrieves the view for the specified view token.
-
#disconnect_participant(params = {}) ⇒ Struct
Disconnects a participant.
-
#get_attachment(params = {}) ⇒ Types::GetAttachmentResponse
Provides a pre-signed URL for download of a completed attachment.
-
#get_authentication_url(params = {}) ⇒ Types::GetAuthenticationUrlResponse
Retrieves the AuthenticationUrl for the current authentication session for the AuthenticateCustomer flow block.
-
#get_transcript(params = {}) ⇒ Types::GetTranscriptResponse
Retrieves a transcript of the session, including details about any attachments.
-
#send_event(params = {}) ⇒ Types::SendEventResponse
The application/vnd.amazonaws.connect.event.connection.acknowledgedContentType is no longer maintained since December 31, 2024. -
#send_message(params = {}) ⇒ Types::SendMessageResponse
Sends a message.
-
#start_attachment_upload(params = {}) ⇒ Types::StartAttachmentUploadResponse
Provides a pre-signed Amazon S3 URL in response for uploading the file directly to S3.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-connectparticipant/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1381 1382 1383 |
# File 'lib/aws-sdk-connectparticipant/client.rb', line 1381 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1384 1385 1386 |
# File 'lib/aws-sdk-connectparticipant/client.rb', line 1384 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 |
# File 'lib/aws-sdk-connectparticipant/client.rb', line 1354 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ConnectParticipant') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-connectparticipant' context[:gem_version] = '1.82.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_participant_authentication(params = {}) ⇒ Struct
Cancels the authentication session. The opted out branch of the Authenticate Customer flow block will be taken.
ConnectionToken is used for invoking this API instead of
ParticipantToken.
The Amazon Connect Participant Service APIs do not use Signature Version 4 authentication.
85 |
# File 'sig/client.rbs', line 85
def cancel_participant_authentication: (
|
#complete_attachment_upload(params = {}) ⇒ Struct
Allows you to confirm that the attachment has been uploaded using the pre-signed URL provided in StartAttachmentUpload API. A conflict exception is thrown when an attachment with that identifier is already being uploaded.
For security recommendations, see Connect Customer Chat security best practices.
ConnectionToken is used for invoking this API instead of
ParticipantToken.
The Amazon Connect Participant Service APIs do not use Signature Version 4 authentication.
95 |
# File 'sig/client.rbs', line 95
def complete_attachment_upload: (
|
#create_participant_connection(params = {}) ⇒ Types::CreateParticipantConnectionResponse
Creates the participant's connection.
For security recommendations, see Connect Customer Chat security best practices.
For WebRTC security recommendations, see Connect Customer WebRTC security best practices.
ParticipantToken is used for invoking this API instead of
ConnectionToken.
The participant token is valid for the lifetime of the participant – until they are part of a contact. For WebRTC participants, if they leave or are disconnected for 60 seconds, a new participant needs to be created using the CreateParticipant API.
For WEBSOCKET Type:
The response URL for has a connect expiry timeout of 100s. Clients must manually connect to the returned websocket URL and subscribe to the desired topic.
For chat, you need to publish the following on the established websocket connection:
{"topic":"aws/subscribe","content":{"topics":["aws/chat"]}}
Upon websocket URL expiry, as specified in the response ConnectionExpiry parameter, clients need to call this API again to obtain a new websocket URL and perform the same steps as before.
The expiry time for the connection token is different than the
ChatDurationInMinutes. Expiry time for the connection token is 1
day.
For WEBRTC_CONNECTION Type:
The response includes connection data required for the client application to join the call using the Amazon Chime SDK client libraries. The WebRTCConnection response contains Meeting and Attendee information needed to establish the media connection.
The attendee join token in WebRTCConnection response is valid for the lifetime of the participant in the call. If a participant leaves or is disconnected for 60 seconds, their participant credentials will no longer be valid, and a new participant will need to be created to rejoin the call.
Message streaming support: This API can also be used together with the StartContactStreaming API to create a participant connection for chat contacts that are not using a websocket. For more information about message streaming, Enable real-time chat message streaming in the Amazon Connect Administrator Guide.
Multi-user web, in-app, video calling support:
For WebRTC calls, this API is used in conjunction with the CreateParticipant API to enable multi-party calling. The StartWebRTCContact API creates the initial contact and routes it to an agent, while CreateParticipant adds additional participants to the ongoing call. For more information about multi-party WebRTC calls, see Enable multi-user web, in-app, and video calling in the Amazon Connect Administrator Guide.
Feature specifications: For information about feature specifications, such as the allowed number of open websocket connections per participant or maximum number of WebRTC participants, see Feature specifications in the Amazon Connect Administrator Guide.
109 |
# File 'sig/client.rbs', line 109
def create_participant_connection: (
|
#describe_view(params = {}) ⇒ Types::DescribeViewResponse
Retrieves the view for the specified view token.
For security recommendations, see Connect Customer Chat security best practices.
121 |
# File 'sig/client.rbs', line 121
def describe_view: (
|
#disconnect_participant(params = {}) ⇒ Struct
Disconnects a participant.
For security recommendations, see Connect Customer Chat security best practices.
ConnectionToken is used for invoking this API instead of
ParticipantToken.
The Amazon Connect Participant Service APIs do not use Signature Version 4 authentication.
131 |
# File 'sig/client.rbs', line 131
def disconnect_participant: (
|
#get_attachment(params = {}) ⇒ Types::GetAttachmentResponse
Provides a pre-signed URL for download of a completed attachment. This is an asynchronous API for use with active contacts.
For security recommendations, see Connect Customer Chat security best practices.
CUSTOM_BOT is not permitted to access
attachments customers may upload. An AccessDeniedException can
indicate that the participant may be a CUSTOM_BOT, and it doesn't
have access to attachments.
ConnectionTokenis used for invoking this API instead ofParticipantToken.
The Amazon Connect Participant Service APIs do not use Signature Version 4 authentication.
144 |
# File 'sig/client.rbs', line 144
def get_attachment: (
|
#get_authentication_url(params = {}) ⇒ Types::GetAuthenticationUrlResponse
Retrieves the AuthenticationUrl for the current authentication session for the AuthenticateCustomer flow block.
For security recommendations, see Connect Customer Chat security best practices.
- The current supported channel is chat. This API is not supported for Apple Messages for Business, WhatsApp, or SMS chats.
ConnectionToken is used for invoking this API instead of
ParticipantToken.
The Amazon Connect Participant Service APIs do not use Signature Version 4 authentication.
156 |
# File 'sig/client.rbs', line 156
def get_authentication_url: (
|
#get_transcript(params = {}) ⇒ Types::GetTranscriptResponse
Retrieves a transcript of the session, including details about any attachments. For information about accessing past chat contact transcripts for a persistent chat, see Enable persistent chat.
For security recommendations, see Connect Customer Chat security best practices.
If you have a process that consumes events in the transcript of an chat that has ended, note that chat transcripts contain the following event content types if the event has occurred during the chat session:
-
application/vnd.amazonaws.connect.event.participant.invited -
application/vnd.amazonaws.connect.event.participant.joined -
application/vnd.amazonaws.connect.event.participant.left -
application/vnd.amazonaws.connect.event.chat.ended -
application/vnd.amazonaws.connect.event.transfer.succeeded -
application/vnd.amazonaws.connect.event.transfer.failed
ConnectionToken is used for invoking this API instead of
ParticipantToken.
The Amazon Connect Participant Service APIs do not use Signature Version 4 authentication.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
170 |
# File 'sig/client.rbs', line 170
def get_transcript: (
|
#send_event(params = {}) ⇒ Types::SendEventResponse
application/vnd.amazonaws.connect.event.connection.acknowledged
ContentType is no longer maintained since December 31, 2024. This
event has been migrated to the CreateParticipantConnection API
using the ConnectParticipant field.
Sends an event. Message receipts are not supported when there are more than two active participants in the chat. Using the SendEvent API for message receipts when a supervisor is barged-in will result in a conflict exception.
For security recommendations, see Connect Customer Chat security best practices.
ConnectionToken is used for invoking this API instead of
ParticipantToken.
The Amazon Connect Participant Service APIs do not use Signature Version 4 authentication.
191 |
# File 'sig/client.rbs', line 191
def send_event: (
|
#send_message(params = {}) ⇒ Types::SendMessageResponse
Sends a message.
For security recommendations, see Connect Customer Chat security best practices.
ConnectionToken is used for invoking this API instead of
ParticipantToken.
The Amazon Connect Participant Service APIs do not use Signature Version 4 authentication.
206 |
# File 'sig/client.rbs', line 206
def send_message: (
|
#start_attachment_upload(params = {}) ⇒ Types::StartAttachmentUploadResponse
Provides a pre-signed Amazon S3 URL in response for uploading the file directly to S3.
For security recommendations, see Connect Customer Chat security best practices.
ConnectionToken is used for invoking this API instead of
ParticipantToken.
The Amazon Connect Participant Service APIs do not use Signature Version 4 authentication.
220 |
# File 'sig/client.rbs', line 220
def start_attachment_upload: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1374 1375 1376 |
# File 'lib/aws-sdk-connectparticipant/client.rb', line 1374 def waiter_names [] end |